.. currentmodule:: xrft

#############
API reference
#############

This page provides an auto-generated summary of xrft's API. For more details
and examples, refer to the relevant chapters in the main part of the
documentation.

xrft
====

.. automodule:: xrft.xrft
  :members:
